FilelikeViewType

Trait FilelikeViewType 

pub unsafe trait FilelikeViewType: FromFilelike + IntoFilelike { }
Available on Hermit or Unix or WASI or Windows only.
Declare that a type is safe to use in a FilelikeView.

Safety

Types implementing this trait declare that if they are constructed with FromFilelike and consumed with IntoFilelike, their IntoFilelike will return the same OwnedFd value that was passed to their FromFilelike.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl FilelikeViewType for File

Implementors

Source

impl FilelikeViewType for OwnedFd

Available on Hermit or Unix or WASI only.